==> lale-0.4.2.tar.gz: lale-0.4.2/lale/lib/lale/aggregate.py <==
# Copyright 2020 IBM Corporation
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import lale.docstrings
import lale.operators
from lale.expressions import Expr

class AggregateImpl:
    def __init__(self, columns, group_by):
        self._hyperparams = { 'columns': columns, 'group_by': group_by}

    def transform(self, X):
        raise NotImplementedError()

_hyperparams_schema = {
    'allOf': [
    {   'description': 'This first sub-object lists all constructor arguments with their types, one at a time, omitting cross-argument constraints, if any.',
        'type': 'object',
        'additionalProperties': False,
        'relevantToOptimizer': [],
        'properties': {
            'columns': {
                'description': 'Aggregations for producing output columns.',
                'anyOf': [
                {   'description': 'Dictionary of output column names and aggregation expressions.',
                    'type': 'object',
                    'additionalProperties': {'laleType': 'expression'}},
                {   'description': 'List of aggregation expressions. The output column name is determined by a heuristic based on the input column name and the transformation function.',
                    'type': 'array',
                    'items': {'laleType': 'expression'}}],
                'default': []},
            'group_by':{
                'description': 'Group by columns for aggregates.',
                'anyOf': [
                {   'description': 'Expressions for columns name if there is a single column.',
                    'laleType': 'expression'},
                {   'description': 'List of expressions for columns.',
                    'type': 'array',
                    'items': {'laleType': 'expression'}}],
                'default': []}}}]}

_input_transform_schema = {
    'type': 'object',
    'required': ['X'],
    'additionalProperties': False,
    'properties': {
        'X': {
            'description': 'The outer array is over rows.',
            'type': 'array',
            'items': {
                'description': 'The inner array is over columns.',
                'type': 'array',
                'items': {'laleType': 'Any'}}}}}

_output_transform_schema = {
    'description': 'The outer array is over rows.',
    'type': 'array',
    'items': {
        'description': 'The inner array is over columns.',
        'type': 'array',
        'items': {'laleType': 'Any'}}}

_combined_schemas = {
  '$schema': 'http://json-schema.org/draft-04/schema#',
  'description': 'Relational algebra aggregate operator.',
  'documentation_url': 'https://lale.readthedocs.io/en/latest/modules/lale.lib.lale.aggregate.html',
  'type': 'object',
  'tags': {
    'pre': [],
    'op': ['transformer'],
    'post': []},
  'properties': {
    'hyperparams': _hyperparams_schema,
    'input_transform': _input_transform_schema,
    'output_transform': _output_transform_schema}}

lale.docstrings.set_docstrings(AggregateImpl, _combined_schemas)

Aggregate = lale.operators.make_operator(AggregateImpl, _combined_schemas)

==> lale-0.4.4.tar.gz: lale-0.4.4/lale/lib/lale/aggregate.py <==
# Copyright 2020 IBM Corporation
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import lale.docstrings
import lale.operators
from lale.expressions import Expr

class AggregateImpl:
    def __init__(self, columns, group_by=[]):
        self._hyperparams = { 'columns': columns, 'group_by': group_by}

    def transform(self, X):
        raise NotImplementedError()

_hyperparams_schema = {
    'allOf': [
    {   'description': 'This first sub-object lists all constructor arguments with their types, one at a time, omitting cross-argument constraints, if any.',
        'type': 'object',
        'additionalProperties': False,
        'relevantToOptimizer': [],
        'properties': {
            'columns': {
                'description': 'Aggregations for producing output columns.',
                'anyOf': [
                {   'description': 'Dictionary of output column names and aggregation expressions.',
                    'type': 'object',
                    'additionalProperties': {'laleType': 'expression'}},
                {   'description': 'List of aggregation expressions. The output column name is determined by a heuristic based on the input column name and the transformation function.',
                    'type': 'array',
                    'items': {'laleType': 'expression'}}],
                'default': []},
            'group_by':{
                'description': 'Group by columns for aggregates.',
                'anyOf': [
                {   'description': 'Expressions for columns name if there is a single column.',
                    'laleType': 'expression'},
                {   'description': 'List of expressions for columns.',
                    'type': 'array',
                    'items': {'laleType': 'expression'}}],
                'default': []}}}]}

_input_transform_schema = {
    'type': 'object',
    'required': ['X'],
    'additionalProperties': False,
    'properties': {
        'X': {
            'description': 'The outer array is over rows.',
            'type': 'array',
            'items': {
                'description': 'The inner array is over columns.',
                'type': 'array',
                'items': {'laleType': 'Any'}}}}}

_output_transform_schema = {
    'description': 'The outer array is over rows.',
    'type': 'array',
    'items': {
        'description': 'The inner array is over columns.',
        'type': 'array',
        'items': {'laleType': 'Any'}}}

_combined_schemas = {
  '$schema': 'http://json-schema.org/draft-04/schema#',
  'description': 'Relational algebra aggregate operator.',
  'documentation_url': 'https://lale.readthedocs.io/en/latest/modules/lale.lib.lale.aggregate.html',
  'type': 'object',
  'tags': {
    'pre': [],
    'op': ['transformer'],
    'post': []},
  'properties': {
    'hyperparams': _hyperparams_schema,
    'input_transform': _input_transform_schema,
    'output_transform': _output_transform_schema}}

lale.docstrings.set_docstrings(AggregateImpl, _combined_schemas)

Aggregate = lale.operators.make_operator(AggregateImpl, _combined_schemas)
